@@ -4,14 +4,18 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
+from pkg_resources import DistributionNotFound, get_distribution
 
-from haystack.constants import DEFAULT_ALIAS
 from haystack import signals
+from haystack.constants import DEFAULT_ALIAS
 from haystack.utils import loading
 
-
 __author__ = 'Daniel Lindsley'
-__version__ = (2, 5, 0)
+
+try:
+    __version__ = get_distribution(__name__).version
+except DistributionNotFound:
+    __version__ = (0, 0, 'dev0')
 
 default_app_config = 'haystack.apps.HaystackConfig'
 
